@@ -1,12 +1,12 @@
 package WordList::ID::Common::Wikipedia1000;
 
-our $DATE = '2017-12-31'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-01-01'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_unicode",0,"longest_word_len",15,"num_words",1000,"num_words_contains_whitespace",0,"avg_word_len",6.585,"shortest_word_len",2,"num_words_contains_nonword_chars",0); # STATS
+our %STATS = ("avg_word_len",6.585,"longest_word_len",15,"num_words_contains_whitespace",0,"shortest_word_len",2,"num_words_contains_unicode",0,"num_words_contains_nonword_chars",0,"num_words",1000); # STATS
 
 1;
 # ABSTRACT: Top 1000 words from Wikipedia Indonesia pages
@@ -21,7 +21,7 @@ WordList::ID::Common::Wikipedia1000 - Top 1000 words from Wikipedia Indonesia pa
 
 =head1 VERSION
 
-This document describes version 0.002 of WordList::ID::Common::Wikipedia1000 (from Perl distribution WordLists-ID-Common), released on 2017-12-31.
+This document describes version 0.003 of WordList::ID::Common::Wikipedia1000 (from Perl distribution WordLists-ID-Common), released on 2018-01-01.
 
 =head1 SYNOPSIS
 
@@ -107,7 +107,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
