@@ -1,12 +1,12 @@
 package WordList::ID::Common::Wikipedia2500;
 
-our $DATE = '2017-12-31'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-01-01'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("shortest_word_len",2,"avg_word_len",7.0716,"num_words_contains_nonword_chars",0,"num_words_contains_whitespace",0,"num_words",2500,"num_words_contains_unicode",0,"longest_word_len",18); # STATS
+our %STATS = ("longest_word_len",18,"avg_word_len",7.074,"shortest_word_len",2,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"num_words",2500,"num_words_contains_nonword_chars",0); # STATS
 
 1;
 # ABSTRACT: Top 2500 words from Wikipedia Indonesia pages
@@ -21,7 +21,7 @@ WordList::ID::Common::Wikipedia2500 - Top 2500 words from Wikipedia Indonesia pa
 
 =head1 VERSION
 
-This document describes version 0.002 of WordList::ID::Common::Wikipedia2500 (from Perl distribution WordLists-ID-Common), released on 2017-12-31.
+This document describes version 0.003 of WordList::ID::Common::Wikipedia2500 (from Perl distribution WordLists-ID-Common), released on 2018-01-01.
 
 =head1 SYNOPSIS
 
@@ -71,17 +71,17 @@ C<work/> directories in the Git repository.
 
 =head1 STATISTICS
 
- +----------------------------------+--------+
- | key                              | value  |
- +----------------------------------+--------+
- | avg_word_len                     | 7.0716 |
- | longest_word_len                 | 18     |
- | num_words                        | 2500   |
- | num_words_contains_nonword_chars | 0      |
- | num_words_contains_unicode       | 0      |
- | num_words_contains_whitespace    | 0      |
- | shortest_word_len                | 2      |
- +----------------------------------+--------+
+ +----------------------------------+-------+
+ | key                              | value |
+ +----------------------------------+-------+
+ | avg_word_len                     | 7.074 |
+ | longest_word_len                 | 18    |
+ | num_words                        | 2500  |
+ | num_words_contains_nonword_chars | 0     |
+ | num_words_contains_unicode       | 0     |
+ | num_words_contains_whitespace    | 0     |
+ | shortest_word_len                | 2     |
+ +----------------------------------+-------+
 
 The statistics is available in the C<%STATS> package variable.
 
@@ -107,7 +107,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -518,6 +518,7 @@ dekat
 delapan
 demi
 demikian
+demokrasi
 dengan
 dengannya
 depan
@@ -2061,7 +2062,6 @@ protein
 protes
 provinsi
 proyek
-public
 publik
 puisi
 pukul
@@ -2289,7 +2289,6 @@ setiap
 setidaknya
 setuju
 sewaktu
-shift
 si
 siang
 siap
@@ -2580,6 +2579,7 @@ utusan
 varian
 variasi
 versi
+vertikal
 via
 video
 virus
