@@ -1,12 +1,12 @@
 package WordList::ID::Common::Wikipedia5000;
 
-our $DATE = '2017-12-31'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-01-01'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_nonword_chars",0,"avg_word_len",7.444,"shortest_word_len",2,"num_words",5000,"num_words_contains_whitespace",0,"longest_word_len",18,"num_words_contains_unicode",0); # STATS
+our %STATS = ("num_words_contains_unicode",0,"avg_word_len",7.4514,"longest_word_len",18,"num_words_contains_whitespace",0,"shortest_word_len",2,"num_words_contains_nonword_chars",0,"num_words",5000); # STATS
 
 1;
 # ABSTRACT: Top 5000 words from Wikipedia Indonesia pages
@@ -21,7 +21,7 @@ WordList::ID::Common::Wikipedia5000 - Top 5000 words from Wikipedia Indonesia pa
 
 =head1 VERSION
 
-This document describes version 0.002 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2017-12-31.
+This document describes version 0.003 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2018-01-01.
 
 =head1 SYNOPSIS
 
@@ -71,17 +71,17 @@ C<work/> directories in the Git repository.
 
 =head1 STATISTICS
 
- +----------------------------------+-------+
- | key                              | value |
- +----------------------------------+-------+
- | avg_word_len                     | 7.444 |
- | longest_word_len                 | 18    |
- | num_words                        | 5000  |
- | num_words_contains_nonword_chars | 0     |
- | num_words_contains_unicode       | 0     |
- | num_words_contains_whitespace    | 0     |
- | shortest_word_len                | 2     |
- +----------------------------------+-------+
+ +----------------------------------+--------+
+ | key                              | value  |
+ +----------------------------------+--------+
+ | avg_word_len                     | 7.4514 |
+ | longest_word_len                 | 18     |
+ | num_words                        | 5000   |
+ | num_words_contains_nonword_chars | 0      |
+ | num_words_contains_unicode       | 0      |
+ | num_words_contains_whitespace    | 0      |
+ | shortest_word_len                | 2      |
+ +----------------------------------+--------+
 
 The statistics is available in the C<%STATS> package variable.
 
@@ -107,7 +107,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -211,7 +211,6 @@ anaknya
 analisis
 analog
 ancaman
-ancient
 anda
 andalan
 aneh
@@ -446,6 +445,7 @@ bepergian
 berabad
 beracun
 berada
+beradaptasi
 berafiliasi
 beragam
 beragama
@@ -806,6 +806,7 @@ caranya
 cari
 cat
 catatan
+catur
 cedera
 celah
 celana
@@ -908,6 +909,7 @@ depannya
 departemen
 depresi
 derajat
+deret
 desa
 desain
 desainer
@@ -1296,6 +1298,7 @@ ditempatkan
 ditempuh
 ditemui
 ditemukan
+ditemukannya
 ditentang
 ditentukan
 diterapkan
@@ -1460,7 +1463,6 @@ fisika
 fisikawan
 fitur
 fleksibel
-flight
 fokus
 form
 formal
@@ -1546,7 +1548,6 @@ gubernur
 gudang
 gugur
 gugus
-guitar
 gula
 gulungan
 guna
@@ -1628,7 +1629,6 @@ hormat
 hormon
 horor
 hotel
-however
 hubungan
 hubungannya
 hujan
@@ -2128,6 +2128,7 @@ ketentuan
 keterampilan
 keterangan
 keterbatasan
+ketergantungan
 keterlibatan
 ketertarikan
 ketiga
@@ -2257,6 +2258,7 @@ koordinat
 kopi
 koran
 korban
+koridor
 korupsi
 kosakata
 kosong
@@ -2798,6 +2800,7 @@ mendadak
 mendaftar
 mendaftarkan
 mendalam
+mendalami
 mendampingi
 mendapat
 mendapati
@@ -2819,6 +2822,7 @@ mendeteksi
 mendiami
 mendidik
 mendirikan
+mendistribusikan
 mendominasi
 mendorong
 menduduki
@@ -3405,7 +3409,6 @@ paroki
 partai
 partikel
 partisipasi
-party
 paru
 paruh
 pas
@@ -3958,7 +3961,6 @@ plasma
 plastik
 plat
 platform
-play
 plot
 plus
 pohon
@@ -3999,6 +4001,7 @@ prasarana
 prasasti
 predator
 predikat
+presentasi
 presenter
 presiden
 prestasi
@@ -4012,7 +4015,6 @@ prinsip
 prioritas
 pro
 problem
-producer
 produk
 produksi
 produksinya
@@ -4043,7 +4045,6 @@ psikologi
 psikologis
 puas
 puasa
-public
 publik
 publikasi
 pucat
@@ -4490,7 +4491,6 @@ setuju
 seumur
 sewa
 sewaktu
-shift
 si
 sia
 siang
@@ -4522,6 +4522,7 @@ singgah
 singkat
 singkatan
 sini
+sinilah
 sintesis
 sinyal
 sipil
@@ -5066,7 +5067,6 @@ virus
 visi
 visual
 vitamin
-vocal
 vokal
 vokalis
 volume
